@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -125,6 +125,7 @@ class DebugUI(QObject):
         debugServer.clientExit.connect(self.__clientExit)
         debugServer.clientSyntaxError.connect(self.__clientSyntaxError)
         debugServer.clientException.connect(self.__clientException)
+        debugServer.clientSignal.connect(self.__clientSignal)
         debugServer.clientVariables.connect(self.__clientVariables)
         debugServer.clientVariable.connect(self.__clientVariable)
         debugServer.clientBreakConditionError.connect(
@@ -999,6 +1000,9 @@ class DebugUI(QObject):
             self.__getThreadList()
             self.__getClientVariables()
 
+        self.debugActGrp.setEnabled(True)
+        self.debugActGrp2.setEnabled(True)
+        
     def __clientExit(self, status):
         """
         Private method to handle the debugged program terminating.
@@ -1076,10 +1080,11 @@ class DebugUI(QObject):
                 filename = os.path.join(self.project.getProjectPath(),
                                         filename)
             else:
-                d = os.path.dirname(
-                    self.project.getMainScript(normalized=True))
-                if os.path.exists(os.path.join(d, filename)):
-                    filename = os.path.join(d, filename)
+                ms = self.project.getMainScript(normalized=True)
+                if ms is not None:
+                    d = os.path.dirname(ms)
+                    if os.path.exists(os.path.join(d, filename)):
+                        filename = os.path.join(d, filename)
         self.viewmanager.setFileLine(filename, lineNo, True, True)
         E5MessageBox.critical(
             self.ui, Program,
@@ -1171,6 +1176,8 @@ class DebugUI(QObject):
                 self.clientStack.emit(stack)
                 self.__getClientVariables()
                 self.ui.setDebugProfile()
+                self.debugActGrp.setEnabled(True)
+                self.debugActGrp2.setEnabled(True)
                 return
             elif res == E5MessageBox.Ignore:
                 if exceptionType not in self.excIgnoreList:
@@ -1184,6 +1191,31 @@ class DebugUI(QObject):
         else:
             self.__continue()
         
+    def __clientSignal(self, message, filename, lineNo, funcName, funcArgs):
+        """
+        Private method to handle a signal generated on the client side.
+        
+        @param message message of the syntax error
+        @type str
+        @param filename translated filename of the syntax error position
+        @type str
+        @param lineNo line number of the syntax error position
+        @type int
+        @param funcName name of the function causing the signal
+        @type str
+        @param funcArgs function arguments
+        @type str
+        """
+        self.ui.raise_()
+        self.ui.activateWindow()
+        QApplication.processEvents()
+        self.viewmanager.setFileLine(filename, lineNo, True)
+        E5MessageBox.critical(
+            self.ui, Program,
+            self.tr("""<p>The program generate the signal "{0}".<br/>"""
+                    """File: <b>{1}</b>, Line: <b>{2}</b></p>""").format(
+                message, filename, lineNo))
+        
     def __clientGone(self, unplanned):
         """
         Private method to handle the disconnection of the debugger client.
@@ -1240,10 +1272,6 @@ class DebugUI(QObject):
             vlist = [('None', '', '')]
             self.debugViewer.showVariables(vlist, False)
         
-        if scope < 1:
-            self.debugActGrp.setEnabled(True)
-            self.debugActGrp2.setEnabled(True)
-        
     def __clientVariable(self, scope, variables):
         """
         Private method to write the contents of a clients classvariable to
@@ -1566,7 +1594,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1685,7 +1713,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1807,7 +1835,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1936,7 +1964,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if debugProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                     tracePython = True  # override flag because it must be true
@@ -1999,7 +2027,7 @@ class DebugUI(QObject):
         
         if not doNotStart:
             if forProject and self.project.getProjectType() in [
-                    "E4Plugin", "E6Plugin"]:
+                    "E6Plugin"]:
                 argv = '--plugin="{0}" {1}'.format(fn, argv)
                 fn = os.path.join(getConfig('ericDir'), "eric6.py")
             
